@@ -8,7 +8,7 @@ package XS::Parse::Sublike;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 require XSLoader;
 XSLoader::load( __PACKAGE__, $VERSION );
@@ -30,10 +30,7 @@ for you.
 
 This module is also highly experimental, consisting currently of pieces of
 code extracted and refactored from L<Future::AsyncAwait> and L<Object::Pad>.
-It is hoped eventually this will be useful for other modules too, as well as
-providing a potential mechanism by which multiple of these kinds of modules
-can coöperate when parsing the same file, and combine their effects. As yet
-this part of the mechanism does not exist.
+It is hoped eventually this will be useful for other modules too.
 
 =head1 XS FUNCTIONS
 
@@ -73,6 +70,27 @@ When the keyword is encountered, the hook's C<permit> function is first tested
 to see if the keyword is permitted at this point. If the function returns true
 then the keyword is consumed and parsed as per L</xs_parse_sublike>.
 
+=head2 xs_parse_sublike_any
+
+   int ret = xs_parse_sublike_any(pTHX_ &hooks, op_ptr)
+
+This function expects to consume an introduction keyword at the lexer position
+which is either C<sub> or the name of another C<sub>-like keyword, which has
+been previously registered using L</register_xs_parse_sublike>. It then
+proceeds to parse the subsequent syntax similar to how it would have parsed if
+encountered by the module's own keyword parser plugin, except that the second
+set of hooks given here also take effect.
+
+If a regular C<sub> is encountered, then this is parsed using the I<hooks> in
+a similar way to C<xs_parse_sublike()>.
+
+If a different registered C<sub>-like keyword is encountered, then parsing is
+performed using B<both> sets of hooks - the ones given to this function as
+well as the ones registered with the keyword. This allows their effects to
+combined. The hooks given by the I<hooks> argument are considered to be on the
+"outside" from those of the registered keyword "inside". The outside ones run
+first for all stages, except C<pre_blockend> which runs them inside-out.
+
 =head1 PARSE HOOKS
 
 The C<XSParseSublikeHooks> structure provides the following hook stages, in
