@@ -8,7 +8,7 @@ package XS::Parse::Sublike::Builder;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 NAME
 
@@ -125,6 +125,7 @@ __DATA__
 #define XSPARSESUBLIKE_ABI_VERSION 1
 
 struct XSParseSublikeHooks {
+  U32  flags;   /* undocumented but reserved for ABI back-compat later */
   bool (*permit)         (pTHX);
   void (*post_blockstart)(pTHX);
   OP * (*pre_blockend)   (pTHX_ OP *body);
@@ -151,6 +152,16 @@ static void S_register_xs_parse_sublike(pTHX_ const char *kw, const struct XSPar
   return (*register_func)(aTHX_ kw, hooks);
 }
 
+static int (*parseany_func)(pTHX_ const struct XSParseSublikeHooks *hooks, OP **op_ptr);
+#define xs_parse_sublike_any(hooks, op_ptr)  S_xs_parse_sublike_any(aTHX_ hooks, op_ptr)
+static int S_xs_parse_sublike_any(pTHX_ const struct XSParseSublikeHooks *hooks, OP **op_ptr)
+{
+  if(!parseany_func)
+    croak("Must call boot_xs_parse_sublike() first");
+
+  return (*parseany_func)(aTHX_ hooks, op_ptr);
+}
+
 #define boot_xs_parse_sublike() S_boot_xs_parse_sublike(aTHX)
 static void S_boot_xs_parse_sublike(pTHX) {
   load_module(PERL_LOADMOD_NOIMPORT, newSVpvs("XS::Parse::Sublike"), NULL, NULL);
@@ -165,6 +176,9 @@ static void S_boot_xs_parse_sublike(pTHX) {
 
   register_func = INT2PTR(void (*)(pTHX_ const char *, const struct XSParseSublikeHooks *),
       SvUV(get_sv("XS::Parse::Sublike::REGISTER", 0)));
+
+  parseany_func = INT2PTR(int (*)(pTHX_ const struct XSParseSublikeHooks *, OP**),
+      SvUV(get_sv("XS::Parse::Sublike::PARSEANY", 0)));
 }
 
 #endif
